@@ -1,6 +1,10 @@
+from ocp_resources.logger import get_logger
 from ocp_resources.utils import TimeoutExpiredError, TimeoutSampler
 
 
+LOGGER = get_logger(name=__name__)
+
+
 def _get_status_condition_log_message(**status_condition):
     log_msg = "Waiting For: \n"
     for status_condition_name, status_condition in status_condition.items():
@@ -56,6 +60,15 @@ class MTV:
         MIGRATION_SUCCEEDED = "The migration has SUCCEEDED."
         HOST_READY = "The host is ready."
 
+    class ConditionCategory:
+        CRITICAL = "Critical"
+
+    class ConditionType:
+        SUCCEEDED = "Succeeded"
+        FAILED = "Failed"
+        TARGET_NAME_NOT_VALID = "TargetNameNotValid"
+        VM_ALREADY_EXISTS = "VMAlreadyExists"
+
     class ProviderType:
         VSPHERE = "vsphere"
         OPENSHIFT = "openshift"
@@ -74,7 +87,7 @@ class MTV:
         Wait for MTV Resource Status Conditions.
         """
 
-        self.logger.info(
+        LOGGER.info(
             _get_status_condition_log_message(
                 condition_status=condition_status,
                 condition_type=condition_type,
@@ -122,7 +135,7 @@ class MTV:
                         return
 
         except TimeoutExpiredError:
-            self.logger.error(
+            LOGGER.error(
                 msg=f"Last Status Condition of {self.kind} {self.name} was: {last_condition}"
             )
             raise
