@@ -1,12 +1,15 @@
 # -*- coding: utf-8 -*-
 
-
 from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT, TIMEOUT_4MINUTES
+from ocp_resources.logger import get_logger
 from ocp_resources.resource import NamespacedResource
 from ocp_resources.utils import TimeoutSampler
 from ocp_resources.virtual_machine_instance import VirtualMachineInstance
 
 
+LOGGER = get_logger(name=__name__)
+
+
 class VirtualMachine(NamespacedResource):
     """
     Virtual Machine object, inherited from Resource.
@@ -26,9 +29,8 @@ class VirtualMachine(NamespacedResource):
         PAUSED = "Paused"
         PROVISIONING = "Provisioning"
         STARTING = "Starting"
-        STOPPED = "Stopped"
+        STOPPED = "stopped"
         STOPPING = "Stopping"
-        WAITING_FOR_VOLUME_BINDING = "WaitingForVolumeBinding"
 
     def __init__(
         self,
@@ -87,11 +89,13 @@ class VirtualMachine(NamespacedResource):
             self.vmi.virt_launcher_pod.wait_deleted()
             return self.vmi.wait_until_running(timeout=timeout, stop_status="dummy")
 
-    def stop(self, timeout=TIMEOUT_4MINUTES, wait=False):
+    def stop(
+        self, timeout=TIMEOUT_4MINUTES, vmi_delete_timeout=TIMEOUT_4MINUTES, wait=False
+    ):
         self.api_request(method="PUT", action="stop")
         if wait:
             self.wait_for_status(timeout=timeout, status=None)
-            return self.vmi.wait_deleted()
+            return self.vmi.wait_deleted(timeout=vmi_delete_timeout)
 
     def wait_for_status(self, status, timeout=TIMEOUT_4MINUTES, sleep=1):
         """
@@ -104,7 +108,7 @@ class VirtualMachine(NamespacedResource):
         Raises:
             TimeoutExpiredError: If timeout reached.
         """
-        self.logger.info(
+        LOGGER.info(
             f"Wait for {self.kind} {self.name} status to be {'ready' if status == True else status}"
         )
         samples = TimeoutSampler(
@@ -158,14 +162,3 @@ class VirtualMachine(NamespacedResource):
             VM printableStatus if VM.status.printableStatus else None
         """
         return self.instance.get("status", {}).get("printableStatus")
-
-    def wait_for_status_none(self, status, timeout=TIMEOUT_4MINUTES):
-        self.logger.info(f"Wait for {self.kind} {self.name} status {status} to be None")
-        for sample in TimeoutSampler(
-            wait_timeout=timeout,
-            sleep=1,
-            exceptions_dict=PROTOCOL_ERROR_EXCEPTION_DICT,
-            func=lambda: self.instance.get("status", {}).get(status),
-        ):
-            if sample is None:
-                return
